==> camel-k-model-v1alpha1-6.3.1-sources.jar: io/fabric8/camelk/v1alpha1/JSONSchemaPropFluent.java <==
package io.fabric8.camelk.v1alpha1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.util.ArrayList;
import java.util.Collection;
import com.fasterxml.jackson.databind.JsonNode;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface JSONSchemaPropFluent<A extends JSONSchemaPropFluent<A>> extends Fluent<A>{
  public JsonNode getDefault();
  public A withDefault(JsonNode _default);
  public Boolean hasDefault();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public A addToEnum(Integer index,JsonNode item);
  public A setToEnum(Integer index,JsonNode item);
  public A addToEnum(com.fasterxml.jackson.databind.JsonNode... items);
  public A addAllToEnum(Collection<JsonNode> items);
  public A removeFromEnum(com.fasterxml.jackson.databind.JsonNode... items);
  public A removeAllFromEnum(Collection<JsonNode> items);
  public List<JsonNode> getEnum();
  public JsonNode getEnum(Integer index);
  public JsonNode getFirstEnum();
  public JsonNode getLastEnum();
  public JsonNode getMatchingEnum(Predicate<JsonNode> predicate);
  public Boolean hasMatchingEnum(Predicate<JsonNode> predicate);
  public A withEnum(List<JsonNode> _enum);
  public A withEnum(com.fasterxml.jackson.databind.JsonNode... _enum);
  public Boolean hasEnum();
  public JsonNode getExample();
  public A withExample(JsonNode example);
  public Boolean hasExample();
  public Boolean getExclusiveMaximum();
  public A withExclusiveMaximum(Boolean exclusiveMaximum);
  public Boolean hasExclusiveMaximum();
  public Boolean getExclusiveMinimum();
  public A withExclusiveMinimum(Boolean exclusiveMinimum);
  public Boolean hasExclusiveMinimum();
  public String getFormat();
  public A withFormat(String format);
  public Boolean hasFormat();
  public String getId();
  public A withId(String id);
  public Boolean hasId();
  public Long getMaxItems();
  public A withMaxItems(Long maxItems);
  public Boolean hasMaxItems();
  public Long getMaxLength();
  public A withMaxLength(Long maxLength);
  public Boolean hasMaxLength();
  public Long getMaxProperties();
  public A withMaxProperties(Long maxProperties);
  public Boolean hasMaxProperties();
  public String getMaximum();
  public A withMaximum(String maximum);
  public Boolean hasMaximum();
  public Long getMinItems();
  public A withMinItems(Long minItems);
  public Boolean hasMinItems();
  public Long getMinLength();
  public A withMinLength(Long minLength);
  public Boolean hasMinLength();
  public Long getMinProperties();
  public A withMinProperties(Long minProperties);
  public Boolean hasMinProperties();
  public String getMinimum();
  public A withMinimum(String minimum);
  public Boolean hasMinimum();
  public String getMultipleOf();
  public A withMultipleOf(String multipleOf);
  public Boolean hasMultipleOf();
  public Boolean getNullable();
  public A withNullable(Boolean nullable);
  public Boolean hasNullable();
  public String getPattern();
  public A withPattern(String pattern);
  public Boolean hasPattern();
  public String getTitle();
  public A withTitle(String title);
  public Boolean hasTitle();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public Boolean getUniqueItems();
  public A withUniqueItems(Boolean uniqueItems);
  public Boolean hasUniqueItems();
  public A addToXDescriptors(Integer index,String item);
  public A setToXDescriptors(Integer index,String item);
  public A addToXDescriptors(java.lang.String... items);
  public A addAllToXDescriptors(Collection<String> items);
  public A removeFromXDescriptors(java.lang.String... items);
  public A removeAllFromXDescriptors(Collection<String> items);
  public List<String> getXDescriptors();
  public String getXDescriptor(Integer index);
  public String getFirstXDescriptor();
  public String getLastXDescriptor();
  public String getMatchingXDescriptor(Predicate<String> predicate);
  public Boolean hasMatchingXDescriptor(Predicate<String> predicate);
  public A withXDescriptors(List<String> xDescriptors);
  public A withXDescriptors(java.lang.String... xDescriptors);
  public Boolean hasXDescriptors();
  public A withExclusiveMaximum();
  public A withExclusiveMinimum();
  public A withNullable();
  public A withUniqueItems();
  
}

==> camel-k-model-v1alpha1-6.7.2-sources.jar: io/fabric8/camelk/v1alpha1/JSONSchemaPropFluent.java <==
package io.fabric8.camelk.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.lang.Long;
import java.util.ArrayList;
import java.util.Collection;
import com.fasterxml.jackson.databind.JsonNode;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface JSONSchemaPropFluent<A extends JSONSchemaPropFluent<A>> extends Fluent<A>{
  public JsonNode getDefault();
  public A withDefault(JsonNode _default);
  public Boolean hasDefault();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  public A addToEnum(int index,JsonNode item);
  public A setToEnum(int index,JsonNode item);
  public A addToEnum(com.fasterxml.jackson.databind.JsonNode... items);
  public A addAllToEnum(Collection<JsonNode> items);
  public A removeFromEnum(com.fasterxml.jackson.databind.JsonNode... items);
  public A removeAllFromEnum(Collection<JsonNode> items);
  public List<JsonNode> getEnum();
  public JsonNode getEnum(int index);
  public JsonNode getFirstEnum();
  public JsonNode getLastEnum();
  public JsonNode getMatchingEnum(Predicate<JsonNode> predicate);
  public Boolean hasMatchingEnum(Predicate<JsonNode> predicate);
  public A withEnum(List<JsonNode> _enum);
  public A withEnum(com.fasterxml.jackson.databind.JsonNode... _enum);
  public Boolean hasEnum();
  public JsonNode getExample();
  public A withExample(JsonNode example);
  public Boolean hasExample();
  public Boolean getExclusiveMaximum();
  public A withExclusiveMaximum(Boolean exclusiveMaximum);
  public Boolean hasExclusiveMaximum();
  public Boolean getExclusiveMinimum();
  public A withExclusiveMinimum(Boolean exclusiveMinimum);
  public Boolean hasExclusiveMinimum();
  public String getFormat();
  public A withFormat(String format);
  public Boolean hasFormat();
  public String getId();
  public A withId(String id);
  public Boolean hasId();
  public Long getMaxItems();
  public A withMaxItems(Long maxItems);
  public Boolean hasMaxItems();
  public Long getMaxLength();
  public A withMaxLength(Long maxLength);
  public Boolean hasMaxLength();
  public Long getMaxProperties();
  public A withMaxProperties(Long maxProperties);
  public Boolean hasMaxProperties();
  public String getMaximum();
  public A withMaximum(String maximum);
  public Boolean hasMaximum();
  public Long getMinItems();
  public A withMinItems(Long minItems);
  public Boolean hasMinItems();
  public Long getMinLength();
  public A withMinLength(Long minLength);
  public Boolean hasMinLength();
  public Long getMinProperties();
  public A withMinProperties(Long minProperties);
  public Boolean hasMinProperties();
  public String getMinimum();
  public A withMinimum(String minimum);
  public Boolean hasMinimum();
  public String getMultipleOf();
  public A withMultipleOf(String multipleOf);
  public Boolean hasMultipleOf();
  public Boolean getNullable();
  public A withNullable(Boolean nullable);
  public Boolean hasNullable();
  public String getPattern();
  public A withPattern(String pattern);
  public Boolean hasPattern();
  public String getTitle();
  public A withTitle(String title);
  public Boolean hasTitle();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public Boolean getUniqueItems();
  public A withUniqueItems(Boolean uniqueItems);
  public Boolean hasUniqueItems();
  public A addToXDescriptors(int index,String item);
  public A setToXDescriptors(int index,String item);
  public A addToXDescriptors(java.lang.String... items);
  public A addAllToXDescriptors(Collection<String> items);
  public A removeFromXDescriptors(java.lang.String... items);
  public A removeAllFromXDescriptors(Collection<String> items);
  public List<String> getXDescriptors();
  public String getXDescriptor(int index);
  public String getFirstXDescriptor();
  public String getLastXDescriptor();
  public String getMatchingXDescriptor(Predicate<String> predicate);
  public Boolean hasMatchingXDescriptor(Predicate<String> predicate);
  public A withXDescriptors(List<String> xDescriptors);
  public A withXDescriptors(java.lang.String... xDescriptors);
  public Boolean hasXDescriptors();
  public A withExclusiveMaximum();
  public A withExclusiveMinimum();
  public A withNullable();
  public A withUniqueItems();
  
}
